@@ -5,6 +5,7 @@ except:
     from urllib.parse import urlparse, parse_qs
 
 from .baseapi import BaseAPI
+from .baseapi import GET
 from .Droplet import Droplet
 from .Region import Region
 from .Size import Size
@@ -14,7 +15,7 @@ from .SSHKey import SSHKey
 from .Action import Action
 from .Account import Account
 from .FloatingIP import FloatingIP
-
+from .Volume import Volume
 
 class Manager(BaseAPI):
     def __init__(self, *args, **kwargs):
@@ -36,9 +37,10 @@ class Manager(BaseAPI):
 
         kwargs["params"] = params
         data = super(Manager, self).get_data(*args, **kwargs)
-        unpaged_data = self.__deal_with_pagination(args[0], data, params)
-
-        return unpaged_data
+        if kwargs.get('type') == GET:
+            return self.__deal_with_pagination(args[0], data, params)
+        else:
+            return data
 
     def __deal_with_pagination(self, url, data, params):
         """
@@ -266,5 +268,23 @@ class Manager(BaseAPI):
         """
         return FloatingIP.get_object(api_token=self.token, ip=ip)
 
+    def get_all_volumes(self):
+        """
+            This function returns a list of Volume objects.
+        """
+        data = self.get_data("volumes")
+        volumes = list()
+        for jsoned in data['volumes']:
+            volume = Volume(**jsoned)
+            volume.token = self.token
+            volumes.append(volume)
+        return volumes
+
+    def get_volume(self, volume_id):
+        """
+            Returns a Volume object by its ID.
+        """
+        return Volume.get_object(api_token=self.token, volume_id=volume_id)
+
     def __str__(self):
         return "%s" % (self.token)
